@@ -32,27 +32,33 @@
 #include <KAction>
 #include <KActionCollection>
 #include <KIcon>
+#include <KMessageWidget>
+#include <KPixmapSequence>
+#include <KPixmapSequenceOverlayPainter>
 #include <KService>
 #include <KToolInvocation>
-#include "kmessagewidget.h"
 
 // LibQApt includes
 #include <LibQApt/Backend>
 
+// Libmuon includes
+#include <Application.h>
+#include <ApplicationBackend.h>
+#include <HistoryView/HistoryView.h>
+
 // Own includes
-#include "../libmuon/HistoryView/HistoryView.h"
-#include "ApplicationBackend.h"
-#include "Application.h"
 #include "ApplicationLauncher.h"
+#include "ApplicationView/ApplicationListView.h"
 #include "AvailableView.h"
+#include "ProgressView.h"
 #include "ViewSwitcher.h"
-#include "ApplicationModel/ApplicationListView.h"
 #include "MuonInstallerSettings.h"
 
 ApplicationWindow::ApplicationWindow()
     : MuonMainWindow()
-    , m_launcherMessage(0)
-    , m_appLauncher(0)
+    , m_launcherMessage(nullptr)
+    , m_appLauncher(nullptr)
+    , m_progressItem(nullptr)
 {
     initGUI();
     QTimer::singleShot(10, this, SLOT(initObject()));
@@ -85,6 +91,16 @@ void ApplicationWindow::initGUI()
     m_viewStack = new QStackedWidget(leftWidget);
     m_viewStack->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 
+    // Busy widget
+    m_busyWidget = new QWidget(m_viewStack);
+    KPixmapSequenceOverlayPainter *busyWidget = new KPixmapSequenceOverlayPainter(m_busyWidget);
+    busyWidget->setSequence(KPixmapSequence("process-working", KIconLoader::SizeSmallMedium));
+    busyWidget->setWidget(m_busyWidget);
+    busyWidget->start();
+
+    m_viewStack->addWidget(m_busyWidget);
+    m_viewStack->setCurrentWidget(m_busyWidget);
+
     m_mainWidget->addWidget(leftWidget);
     loadSplitterSizes();
 
@@ -107,11 +123,11 @@ void ApplicationWindow::initObject()
     connect(m_appBackend, SIGNAL(appBackendReady()),
             this, SLOT(populateViews()));
     connect(m_appBackend, SIGNAL(reloadStarted()),
-            this, SLOT(clearViews()));
-    connect(m_appBackend, SIGNAL(reloadFinished()),
-            this, SLOT(populateViews()));
+            this, SLOT(removeProgressItem()));
     connect(m_appBackend, SIGNAL(reloadFinished()),
             this, SLOT(showLauncherMessage()));
+    connect(m_appBackend, SIGNAL(startingFirstTransaction()),
+            this, SLOT(addProgressItem()));
 
     MuonMainWindow::initObject();
     // Our modified ApplicationBackend provides us events in a way that
@@ -253,6 +269,7 @@ void ApplicationWindow::populateViews()
     m_viewHash[installedItem->index()] = 0;
 
     parentItem = availableItem;
+    kDebug() << originNames.size();
     foreach(const QString &originName, originNames) {
         QString originLabel = m_backend->originLabel(originName);
         QStandardItem *viewItem = new QStandardItem;
@@ -376,15 +393,16 @@ void ApplicationWindow::changeView(const QModelIndex &index)
         case AppView: {
             QString originFilter = index.data(OriginFilterRole).toString();
             QApt::Package::State stateFilter = (QApt::Package::State)index.data(StateFilterRole).toInt();
+
             view = new ApplicationListView(this, m_appBackend, index);
             ApplicationListView *appView = static_cast<ApplicationListView *>(view);
-            m_viewStack->addWidget(view);
             appView->setBackend(m_backend);
             appView->setStateFilter(stateFilter);
             appView->setOriginFilter(originFilter);
-            if (originFilter.contains(QLatin1String("LP-PPA"))) {
+            appView->setCanShowTechnical(true);
+
+            if (originFilter != QLatin1String("Ubuntu") && originFilter != QLatin1String("Debian"))
                 appView->setShouldShowTechnical(true);
-            }
         }
         break;
         case CatView: {
@@ -392,19 +410,30 @@ void ApplicationWindow::changeView(const QModelIndex &index)
 
             AvailableView *availableView = static_cast<AvailableView *>(view);
             availableView->setBackend(m_backend);
-            m_viewStack->addWidget(view);
         }
             break;
         case History:
             view = new HistoryView(this);
-            m_viewStack->addWidget(view);
+            break;
+        case Progress: {
+            view = new ProgressView(this, m_appBackend);
+            ProgressView *pView = (ProgressView *)view;
+            connect(pView, SIGNAL(lastTransactionCancelled()), this, SLOT(removeProgressItem()));
+        }
         case InvalidView:
         default:
             break;
         }
+
+        m_viewStack->addWidget(view);
     }
 
+    m_viewStack->addWidget(view);
     m_viewStack->setCurrentWidget(view);
+    m_viewStack->removeWidget(m_busyWidget);
+
+    delete m_busyWidget;
+    m_busyWidget = nullptr;
 
     m_viewHash[index] = view;
 }
@@ -425,6 +454,8 @@ void ApplicationWindow::runSourcesEditor()
 void ApplicationWindow::sourcesEditorFinished(int reload)
 {
     m_appBackend->reload();
+    clearViews();
+    populateViews();
     MuonMainWindow::sourcesEditorFinished(reload);
 }
 
@@ -436,40 +467,22 @@ ApplicationBackend *ApplicationWindow::appBackend() const
 void ApplicationWindow::showLauncherMessage()
 {
     clearMessageActions();
-    QApt::PackageList packages;
 
-    foreach (const QString &package, m_appBackend->launchList()) {
-        QApt::Package *pkg = m_backend->package(package);
-        if (pkg) {
-            packages << pkg;
+    QVector<KService::Ptr> apps;
+    foreach (Application *app, m_appBackend->launchList()) {
+        app->clearPackage();
+        app->package(); // Regenerate package
+        if (!app->isInstalled()) {
+            continue;
         }
+        apps << app->executables();
     }
 
     m_appBackend->clearLaunchList();
-
-    QVector<KService *> apps;
-    foreach (QApt::Package *package, packages) {
-        if (!package->isInstalled()) {
-            continue;
-        }
-
-        // TODO: move to Application (perhaps call it Application::executables())
-        foreach (const QString &desktop, package->installedFilesList().filter(".desktop")) {
-            // we create a new KService because findByDestopPath
-            // might fail because the Sycoca database is not up to date yet.
-            KService *service = new KService(desktop);
-            if (service->isApplication() &&
-              !service->noDisplay() &&
-              !service->exec().isEmpty())
-            {
-                apps << service;
-            }
-        }
-    }
     m_launchableApps = apps;
 
     if (apps.size() == 1) {
-        KService *service = apps.first();
+        KService::Ptr service = apps.first();
         QString name = service->genericName().isEmpty() ?
                        service->property("Name").toString() :
                        service->property("Name").toString() % QLatin1Literal(" - ") % service->genericName();
@@ -499,7 +512,7 @@ void ApplicationWindow::launchSingleApp()
 void ApplicationWindow::showAppLauncher()
 {
     if (!m_appLauncher && !m_launchableApps.isEmpty()) {
-        m_appLauncher = new ApplicationLauncher(m_launchableApps);
+        m_appLauncher = new ApplicationLauncher(m_appBackend);
         connect(m_appLauncher, SIGNAL(destroyed(QObject*)),
             this, SLOT(onAppLauncherClosed()));
         connect(m_appLauncher, SIGNAL(finished(int)),
@@ -522,4 +535,35 @@ void ApplicationWindow::clearMessageActions()
     }
 }
 
+void ApplicationWindow::addProgressItem()
+{
+    QStandardItem *parentItem = m_viewModel->invisibleRootItem();
+
+    if (m_progressItem)
+        return;
+
+    m_progressItem = new QStandardItem;
+    m_progressItem->setEditable(false);
+    m_progressItem->setIcon(KIcon("download").pixmap(32,32));
+    m_progressItem->setText(i18nc("@item:inlistbox Item for showing the progress view", "In Progress"));
+    m_progressItem->setData(Progress, ViewTypeRole);
+    parentItem->appendRow(m_progressItem);
+
+    m_viewHash[m_progressItem->index()] = 0;
+}
+
+void ApplicationWindow::removeProgressItem()
+{
+    if (!m_progressItem)
+        return;
+
+    QObject *progressView = m_viewHash[m_progressItem->index()];
+    if (progressView)
+            progressView->deleteLater();
+
+    m_viewHash.remove(m_progressItem->index());
+    m_viewModel->removeRow(m_viewModel->indexFromItem(m_progressItem).row());
+    m_progressItem = nullptr;
+}
+
 #include "ApplicationWindow.moc"
