@@ -297,6 +297,7 @@ bool ApplicationBackend::confirmRemoval(Transaction *transaction)
     // Find changes due to markings
     QApt::PackageList excluded;
     excluded.append(transaction->application()->package());
+    excluded.append(transaction->addons().keys());
     QApt::StateChanges changes = m_backend->stateChanges(oldCacheState, excluded);
     // Restore cache state, we're only checking at the moment
     m_backend->restoreCacheState(oldCacheState);
@@ -331,7 +332,7 @@ void ApplicationBackend::markTransaction(Transaction *transaction)
     QHash<QApt::Package *, QApt::Package::State> addons = transaction->addons();
     auto iter = addons.constBegin();
 
-    QApt::Package *package;
+    QApt::Package *package = nullptr;
     QApt::Package::State state;
     while (iter != addons.constEnd()) {
         package = iter.key();
@@ -360,7 +361,7 @@ void ApplicationBackend::markLangpacks(Transaction *transaction)
     QString pkgName = transaction->application()->packageName();
 
     QStringList args;
-    args << prog << QLatin1String("-l") << language << pkgName;
+    args << prog << QLatin1String("-l") << language << QLatin1String("-p") << pkgName;
 
     KProcess proc;
     proc.setOutputChannelMode(KProcess::OnlyStdoutChannel);
@@ -375,7 +376,7 @@ void ApplicationBackend::markLangpacks(Transaction *transaction)
     m_backend->setCompressEvents(true);
     foreach(const QString &pkg, res.split(' '))
     {
-        langPack = m_backend->package(pkg);
+        langPack = m_backend->package(pkg.trimmed());
 
         if (langPack)
             langPack->setInstall();
