@@ -70,6 +70,7 @@ UpdaterWidget::UpdaterWidget(QWidget *parent) :
     m_updateView->setAlternatingRowColors(true);
     m_updateView->header()->setResizeMode(0, QHeaderView::Stretch);
     m_updateView->header()->setResizeMode(1, QHeaderView::ResizeToContents);
+    m_updateView->header()->setResizeMode(2, QHeaderView::ResizeToContents);
     m_updateView->header()->setStretchLastSection(false);
     m_updateView->setModel(m_updateModel);
     connect(m_updateView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -216,19 +217,23 @@ void UpdaterWidget::populateUpdateModel()
         m_upgradeableApps.append(app);
     }
 
+    // Add populated items to the model
     if (securityItem->childCount()) {
+        securityItem->sort();
         m_updateModel->addItem(securityItem);
     } else {
         delete securityItem;
     }
 
     if (appItem->childCount()) {
+        appItem->sort();
         m_updateModel->addItem(appItem);
     } else {
         delete appItem;
     }
 
     if (systemItem->childCount()) {
+        systemItem->sort();
         m_updateModel->addItem(systemItem);
     } else {
         delete systemItem;
